<?php

namespace Drupal\duration_field\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;

/**
 * Provides a time format formatter for the Duration field type.
 *
 * @FieldFormatter(
 *   id = "duration_time_display",
 *   label = @Translation("Time Format"),
 *   field_types = {
 *     "duration"
 *   }
 * )
 */
class DurationTimeFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {

    $summary = [];

    $summary[] = t('Displays the duration in the format: @format', ['@format' => $this->getDisplayFormat()]);

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {

      $element[$delta] = [
        '#theme' => 'duration_field_duration_time',
        '#item' => $item->get('duration')->getCastedValue(),
      ];
    }

    return $element;
  }

  /**
   * Generate the format that will be shown to users in the settings overview.
   */
  protected function getDisplayFormat() {

    $granularity = $this->getFieldSetting('granularity');

    $parts = [];
    if ($granularity['year'] || $granularity['month'] || $granularity['day']) {
      $parts[] = 'YY-MM-DD';
    }

    if ($granularity['hour'] || $granularity['minute'] || $granularity['second']) {
      $parts[] = 'HH:MM:SS';
    }

    return implode(' ', $parts);
  }

}
